@@ -524,7 +524,10 @@ class Smart(Generic[T]):
         """
         metadata = dict(
             **self.lab.metadata(),
-            params=self.representation(),
+            params=typeutil.convert_to_primitive_types(
+                obj=self.dict,
+                missing_value=self.missing_value,
+            ),
         )
 
         if save_to:
