@@ -1,9 +1,9 @@
 import os
 import unittest
 
-from smartparams.utils import str_to_bool
+import smartparams.utils.string as strutil
 
-_INTEGRATION = str_to_bool(os.getenv('TEST_INTEGRATION', default='1'))
+_INTEGRATION = strutil.to_bool(os.getenv('TEST_INTEGRATION', default='1'))
 
 
 @unittest.skipUnless(_INTEGRATION, reason="Integration tests are disabled")
