@@ -127,6 +127,11 @@ class TestSmartRepresentationCase(IntegrationCase):
     def tearDown(self) -> None:
         self.smart.register.reset()
 
+    def test_representation(self) -> None:
+        actual = self.smart.representation()
+
+        self.assertEqual({}, actual)
+
     def test_object_representation__with_defaults(self) -> None:
         class_name = f"{Class.__module__}.{Class.__qualname__}"
         class_child_name = f"{ClassChild.__module__}.{ClassChild.__qualname__}"
