@@ -134,13 +134,9 @@ class TestRegisterCase(UnitCase):
             'host': 'node',
             'os': 'node',
             'python': 'python_version',
-            'script': '/script.py',
             'args': ['arg1', 'arg2'],
-            'git': {},
             'branch': 'master',
             'commit': None,
-            'uncommited_files': [],
-            'untracted_files': [],
             'packages': [],
         }
         with TemporaryDirectory() as dirname:
